@@ -1,26 +1,70 @@
+// ConversionManager.h
+//
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
 #ifndef __conversion_manager_h__
 #define __conversion_manager_h__
 
 #include "ConversionHelper.h"
+#include "AlphabetManager.h"
 #include "DasherModel.h"
 #include "DasherTypes.h"
 #include "LanguageModelling/LanguageModel.h" // Urgh - we really shouldn't need to know about language models here
 #include "NodeManager.h"
+#include "SCENode.h"
 
 #include <vector>
 
+// TODO: Conversion manager needs to deal with offsets and contexts - Will: See Phil for an explanation.
+
 namespace Dasher {
   class CDasherNode; // Forward declaration
 
+  /// \ingroup Model
+  /// @{
+
+  /// This class manages nodes in conversion subtrees, typically used
+  /// for languages where complex characters are entered through a
+  /// composition process, for example Japanese and Chinese. 
   ///
-  /// Conversion manager class - handles nodes representing the
-  /// conversion of strings in languages where symbols are converted
+  /// A new CConversionManager is created for each subtree, and
+  /// therefore represents the conversion of a single phrase. The
+  /// phrase to be converted is read by recursing through the parent
+  /// tree. An instance of CConversionHelper is shared by several
+  /// CConversionManagers, and performs the language dependent aspects
+  /// of conversion. Specifically construction of the candidate
+  /// lattice and assignment of weights.
+  ///
+  /// The general policy is to delay computation as far as possible,
+  /// to avoid unnecessary computational load. The candidate lattice
+  /// is therefore built at the first call to PopulateChildren, and
+  /// weights are only assigned when the appropriate node has its
+  /// child list populated.
+  ///
+  /// See CConversionHelper for details of the language specific
+  /// aspects of conversion, and CNodeManager for details of the node
+  /// management process.
   ///
-  
   class CConversionManager : public CNodeManager {
   public:
     // TODO: We shouldn't need to know about this stuff, but the code is somewhat in knots at the moment
-    CConversionManager(CNodeCreationManager *pNCManager, CConversionHelper *pHelper, int CMid);
+    CConversionManager(CNodeCreationManager *pNCManager, CConversionHelper *pHelper, CAlphabet *pAlphabet, int CMid);
     ~CConversionManager();
 
     ///
@@ -38,8 +82,13 @@ namespace Dasher {
     virtual void Unref() {
       --m_iRefCount;
 
-      if(m_iRefCount == 0)
+
+      //      std::cout << "Unref, new count = " << m_iRefCount << std::endl;
+
+      if(m_iRefCount == 0) {
+	//	std::cout << "Deleting " << this << std::endl;
 	delete this;
+      }
     };
 
     ///
@@ -57,7 +106,7 @@ namespace Dasher {
     /// normalisation constant
     ///
     
-    virtual void AssignChildSizes(SCENode *pNode, int *pSizes, int iNChildren);
+    virtual void AssignChildSizes(SCENode **pNode, CLanguageModel::Context context, int iNChildren);
 
     ///
     /// Provide children for the supplied node
@@ -100,10 +149,12 @@ namespace Dasher {
     /// Rebuild the parent of a given node - used for when backoff occurs beyond the start of the tree
     ///
 
-    virtual CDasherNode *RebuildParent(CDasherNode *pNode, int iGeneration) {
+    virtual CDasherNode *RebuildParent(CDasherNode *pNode) {
       return 0;
     }
 
+    virtual void SetFlag(CDasherNode *pNode, int iFlag, bool bValue);
+
   private:
 
     /// 
@@ -114,12 +165,6 @@ namespace Dasher {
     
     void BuildTree(CDasherNode *pRoot);
 
-    /// 
-    /// Recursively delete the conversion tree when we're done
-    ///
-
-    bool RecursiveDelTree(SCENode* pNode);
-
     /// 
     /// Dump tree to stdout (debug)
     ///
@@ -156,10 +201,16 @@ namespace Dasher {
     
     CConversionHelper *m_pHelper;
 
+    CAlphabet *m_pAlphabet;
+
     ///
     /// Reference count 
     ///
 
+
+    CLanguageModel::Context m_iLearnContext;
+
+    
     int m_iRefCount;
 
     ///
@@ -169,7 +220,20 @@ namespace Dasher {
     ///
 
     int m_iCMID;
+
+    //TODO: REVISE
+    struct SConversionData {
+      //     symbol iSymbol;
+      //     int iPhase;
+      CLanguageModel *pLanguageModel;
+      CLanguageModel::Context iContext;
+      SCENode * pSCENode;
+      bool bType; // True for termial nodes (bit of a hack)
+      int iOffset;
+      //int iGameOffset;
+    };
   };
+  /// @}
 }
 
 #endif
