@@ -148,11 +148,15 @@ DasherExternalBuffer *dasher_external_buffer_new() {
   DasherExternalBuffer *pDasherControl;
   pDasherControl = (DasherExternalBuffer *)(g_object_new(dasher_external_buffer_get_type(), NULL));
 
+  g_message("1");
+
 #ifdef GNOME_A11Y
+  g_message("2");
+
   DasherExternalBufferPrivate *pPrivate = (DasherExternalBufferPrivate *)(pDasherControl->private_data);
 
   if(SPI_init() == 2) {
-    g_message("Could not initilaise SPI - accessibility options disabled");
+    g_message("Could not initialise SPI - accessibility options disabled");
     pPrivate->bSPIInit = false;
   }
   else {
