@@ -1,5 +1,7 @@
 #include "config.h"
 
+#include <cstring>
+
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <glade/glade.h>
@@ -9,6 +11,7 @@
 #include <hildon-widgets/hildon-program.h>
 #endif
 #include <libgnome/libgnome.h>
+#include <unistd.h>
 
 #include "GtkDasherControl.h"
 #include "KeyboardHelper.h"
